pm4py.objects.random\_variables.lognormal package
=================================================

Submodules
----------

pm4py.objects.random\_variables.lognormal.random\_variable module
-----------------------------------------------------------------

.. automodule:: pm4py.objects.random_variables.lognormal.random_variable
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.objects.random_variables.lognormal
   :members:
   :undoc-members:
   :show-inheritance:
